==> openx-2.5.66-beta.tar.gz: openx-2.5.66-beta/plugins/deliveryLimitations/Geo/City.res.inc.php <==
<?php

/*
+---------------------------------------------------------------------------+
| OpenX v2.5                                                                |
| ==========                                                                |
|                                                                           |
| Copyright (c) 2003-2008 OpenX Limited                                     |
| For contact details, see: http://www.openx.org/                           |
|                                                                           |
| This program is free software; you can redistribute it and/or modify      |
| it under the terms of the GNU General Public License as published by      |
| the Free Software Foundation; either version 2 of the License, or         |
| (at your option) any later version.                                       |
|                                                                           |
| This program is distributed in the hope that it will be useful,           |
| but WITHOUT ANY WARRANTY; without even the implied warranty of            |
| MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             |
| GNU General Public License for more details.                              |
|                                                                           |
| You should have received a copy of the GNU General Public License         |
| along with this program; if not, write to the Free Software               |
| Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA |
+---------------------------------------------------------------------------+
$Id: City.res.inc.php 18135 2008-03-27 13:21:12Z andrew.hill@openx.org $
*/

/**
 * @package    OpenXPlugin
 * @subpackage DeliveryLimitations
 * @author     Chris Nutting <chris.nutting@openx.org>
 * @author     Matteo Beccati <matteo.beccati@openx.org>
 */

if (!isset($GLOBALS['_MAX']['_GEOCACHE']['city'])) {
    require MAX_PATH . '/plugins/deliveryLimitations/Geo/data/res-iso3166.inc.php';
    require MAX_PATH . '/plugins/deliveryLimitations/Geo/Country.res.inc.php';

    foreach ($OA_Geo_ISO3166_MaxMind as $v) {
        unset($res[$v]);
    }

    $res = array('' => MAX_Plugin_Translation::translate('---Any---', $this->module, $this->package)) +
        $res;

    $GLOBALS['_MAX']['_GEOCACHE']['city'] = $res;
} else {
    $res = $GLOBALS['_MAX']['_GEOCACHE']['city'];
}

?>

==> openx-2.5.67-beta.tar.gz: openx-2.5.67-beta/plugins/deliveryLimitations/Geo/City.res.inc.php <==
<?php

/*
+---------------------------------------------------------------------------+
| OpenX v2.5                                                                |
| ==========                                                                |
|                                                                           |
| Copyright (c) 2003-2008 OpenX Limited                                     |
| For contact details, see: http://www.openx.org/                           |
|                                                                           |
| This program is free software; you can redistribute it and/or modify      |
| it under the terms of the GNU General Public License as published by      |
| the Free Software Foundation; either version 2 of the License, or         |
| (at your option) any later version.                                       |
|                                                                           |
| This program is distributed in the hope that it will be useful,           |
| but WITHOUT ANY WARRANTY; without even the implied warranty of            |
| MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             |
| GNU General Public License for more details.                              |
|                                                                           |
| You should have received a copy of the GNU General Public License         |
| along with this program; if not, write to the Free Software               |
| Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA |
+---------------------------------------------------------------------------+
$Id: City.res.inc.php 19860 2008-05-06 09:47:57Z david.keen@openx.org $
*/

/**
 * @package    OpenXPlugin
 * @subpackage DeliveryLimitations
 * @author     Chris Nutting <chris.nutting@openx.org>
 * @author     Matteo Beccati <matteo.beccati@openx.org>
 */

if (!isset($GLOBALS['_MAX']['_GEOCACHE']['city'])) {
    require MAX_PATH . '/plugins/deliveryLimitations/Geo/data/res-iso3166.inc.php';
    require MAX_PATH . '/plugins/deliveryLimitations/Geo/Country.res.inc.php';

    foreach ($OA_Geo_ISO3166_MaxMind as $k => $v) {
        unset($res[$k]);
    }

    $res = array('' => MAX_Plugin_Translation::translate('---Any---', $this->module, $this->package)) +
        $res;

    $GLOBALS['_MAX']['_GEOCACHE']['city'] = $res;
} else {
    $res = $GLOBALS['_MAX']['_GEOCACHE']['city'];
}

?>
